// Colors
$text-color: #868686;
$heading-color: #222222;
$bg-light: #f9f9f9;
$bg-dark: #181818;
$border-color: #e5e5e5;
$border-color-dark: #313131;
$main-color: #ffb31a;
$secondary-color: #2f95ef;
$meta-color: #9e9e9e;


// Fonts
$body-font: 'Open Sans', sans-serif;
$heading-font: 'Barlow', sans-serif;


// Navbar
$nav-height: 95px;
$nav-short-height: 60px;